@@ -2,11 +2,13 @@ from pathlib import Path
 from typing import Optional, Union
 
 import numpy as np
+import PIL
 import torch
+from PIL.Image import Image as TPILImage
 from pytorch_grad_cam.utils.image import show_cam_on_image
 from torch import nn
 
-from oml.const import MEAN, STD, STORAGE_URL, TNormParam
+from oml.const import MEAN, STD, STORAGE_CKPTS, TNormParam
 from oml.interfaces.models import IExtractor
 from oml.models.utils import remove_prefix_from_state_dict
 from oml.models.vit.hubconf import (  # type: ignore
@@ -17,9 +19,9 @@ from oml.models.vit.hubconf import (  # type: ignore
 )
 from oml.transforms.images.albumentations.transforms import get_normalisation_albu
 from oml.utils.io import download_checkpoint_one_of
+from oml.utils.misc_torch import normalise, temporary_setting_model_mode
 
 _FB_URL = "https://dl.fbaipublicfiles.com"
-_STORAGE_CKPTS = STORAGE_URL + "/download/checkpoints"
 
 
 class ViTExtractor(IExtractor):
@@ -32,31 +34,55 @@ class ViTExtractor(IExtractor):
 
     pretrained_models = {
         # checkpoints pretrained in DINO framework on ImageNet by MetaAI
-        "vits16_dino": (f"{_FB_URL}/dino/dino_deitsmall16_pretrain/dino_deitsmall16_pretrain.pth", "cf0f22", None),
-        "vits8_dino": (f"{_FB_URL}/dino/dino_deitsmall8_pretrain/dino_deitsmall8_pretrain.pth", "230cd5", None),
-        "vitb16_dino": (f"{_FB_URL}/dino/dino_vitbase16_pretrain/dino_vitbase16_pretrain.pth", "552daf", None),
-        "vitb8_dino": (f"{_FB_URL}/dino/dino_vitbase8_pretrain/dino_vitbase8_pretrain.pth", "556550", None),
+        "vits16_dino": {
+            "url": f"{_FB_URL}/dino/dino_deitsmall16_pretrain/dino_deitsmall16_pretrain.pth",
+            "hash": "cf0f22",
+            "fname": "vits16_dino.ckpt",
+            "init_args": {"arch": "vits16", "normalise_features": False},
+        },
+        "vits8_dino": {
+            "url": f"{_FB_URL}/dino/dino_deitsmall8_pretrain/dino_deitsmall8_pretrain.pth",
+            "hash": "230cd5",
+            "fname": "vits8_dino.ckpt",
+            "init_args": {"arch": "vits8", "normalise_features": False},
+        },
+        "vitb16_dino": {
+            "url": f"{_FB_URL}/dino/dino_vitbase16_pretrain/dino_vitbase16_pretrain.pth",
+            "hash": "552daf",
+            "fname": "vitb16_dino.ckpt",
+            "init_args": {"arch": "vitb16", "normalise_features": False},
+        },
+        "vitb8_dino": {
+            "url": f"{_FB_URL}/dino/dino_vitbase8_pretrain/dino_vitbase8_pretrain.pth",
+            "hash": "556550",
+            "fname": "vitb8_dino.ckpt",
+            "init_args": {"arch": "vitb8", "normalise_features": False},
+        },
         # our pretrained checkpoints
-        "vits16_inshop": (
-            [f"{_STORAGE_CKPTS}/inshop/vits16_inshop_a76b85.ckpt", "1niX-TC8cj6j369t7iU2baHQSVN3MVJbW"],
-            "a76b85",
-            "vits16_inshop.ckpt",
-        ),
-        "vits16_sop": (
-            [f"{_STORAGE_CKPTS}/sop/vits16_sop_21e743.ckpt", "1zuGRHvF2KHd59aw7i7367OH_tQNOGz7A"],
-            "21e743",
-            "vits16_sop.ckpt",
-        ),
-        "vits16_cub": (
-            [f"{_STORAGE_CKPTS}/cub/vits16_cub.ckpt", "1p2tUosFpGXh5sCCdzlXtjV87kCDfG34G"],
-            "e82633",
-            "vits16_cub.ckpt",
-        ),
-        "vits16_cars": (
-            [f"{_STORAGE_CKPTS}/cars/vits16_cars.ckpt", "1hcOxDRRXrKr6ZTCyBauaY8Ue-pok4Icg"],
-            "9f1e59",
-            "vits16_cars.ckpt",
-        ),
+        "vits16_inshop": {
+            "url": [f"{STORAGE_CKPTS}/inshop/vits16_inshop_a76b85.ckpt", "1niX-TC8cj6j369t7iU2baHQSVN3MVJbW"],
+            "hash": "a76b85",
+            "fname": "vits16_inshop.ckpt",
+            "init_args": {"arch": "vits16", "normalise_features": False},
+        },
+        "vits16_sop": {
+            "url": [f"{STORAGE_CKPTS}/sop/vits16_sop_21e743.ckpt", "1zuGRHvF2KHd59aw7i7367OH_tQNOGz7A"],
+            "hash": "21e743",
+            "fname": "vits16_sop.ckpt",
+            "init_args": {"arch": "vits16", "normalise_features": True},
+        },
+        "vits16_cub": {
+            "url": [f"{STORAGE_CKPTS}/cub/vits16_cub.ckpt", "1p2tUosFpGXh5sCCdzlXtjV87kCDfG34G"],
+            "hash": "e82633",
+            "fname": "vits16_cub.ckpt",
+            "init_args": {"arch": "vits16", "normalise_features": False},
+        },
+        "vits16_cars": {
+            "url": [f"{STORAGE_CKPTS}/cars/vits16_cars.ckpt", "1hcOxDRRXrKr6ZTCyBauaY8Ue-pok4Icg"],
+            "hash": "9f1e59",
+            "fname": "vits16_cars.ckpt",
+            "init_args": {"arch": "vits16", "normalise_features": False},
+        },
     }
 
     def __init__(
@@ -65,7 +91,6 @@ class ViTExtractor(IExtractor):
         arch: str,
         normalise_features: bool,
         use_multi_scale: bool = False,
-        strict_load: bool = True,
     ):
         """
         Args:
@@ -75,8 +100,7 @@ class ViTExtractor(IExtractor):
             arch: Might be one of ``vits8``, ``vits16``, ``vitb8``, ``vitb16``. You can check all the available options
              in ``self.constructors``
             normalise_features: Set ``True`` to normalise output features
-            use_multi_scale: Set ``True`` to use multi scale (the analogue of test time augmentations)
-            strict_load: Set ``True`` if you want the strict load of the weights from the checkpoint
+            use_multi_scale: Set ``True`` to use multiscale (the analogue of test time augmentations)
 
         """
         assert arch in self.constructors
@@ -93,15 +117,17 @@ class ViTExtractor(IExtractor):
             return
 
         if weights in self.pretrained_models:
-            url_or_fid, hash_md5, fname = self.pretrained_models[weights]  # type: ignore
+            pretrained = self.pretrained_models[weights]  # type: ignore
             weights = download_checkpoint_one_of(
-                url_or_fid_list=url_or_fid, hash_md5=hash_md5, fname=fname  # type: ignore
+                url_or_fid_list=pretrained["url"],  # type: ignore
+                hash_md5=pretrained["hash"],  # type: ignore
+                fname=pretrained["fname"],  # type: ignore
             )
 
         ckpt = torch.load(weights, map_location="cpu")
         state_dict = ckpt["state_dict"] if "state_dict" in ckpt else ckpt
         ckpt = remove_prefix_from_state_dict(state_dict, trial_key="norm.bias")
-        self.model.load_state_dict(ckpt, strict=strict_load)
+        self.model.load_state_dict(ckpt, strict=True)
 
     def forward(self, x: torch.Tensor) -> torch.Tensor:
         if self.mscale:
@@ -110,8 +136,7 @@ class ViTExtractor(IExtractor):
             x = self.model(x)
 
         if self.normalise_features:
-            xn = torch.linalg.norm(x, 2, dim=1).detach()
-            x = x.div(xn.unsqueeze(1))
+            x = normalise(x)
 
         return x
 
@@ -136,16 +161,27 @@ class ViTExtractor(IExtractor):
         # v /= v.norm(dim=1)  # we don't want to shift the norms values
         return v
 
-    def draw_attention(self, image: np.ndarray) -> np.ndarray:
+    def draw_attention(self, image: Union[TPILImage, np.ndarray]) -> np.ndarray:
         """
+        Args:
+            image: An image with pixel values in the range of ``[0..255]``.
+
+        Returns:
+            An image with drawn attention maps.
+
         Visualization of the multi-head attention on a particular image.
 
         """
         return vis_vit(vit=self, image=image)
 
 
-def vis_vit(vit: ViTExtractor, image: np.ndarray, mean: TNormParam = MEAN, std: TNormParam = STD) -> np.ndarray:
-    vit.eval()
+def vis_vit(
+    vit: ViTExtractor, image: Union[TPILImage, np.ndarray], mean: TNormParam = MEAN, std: TNormParam = STD
+) -> np.ndarray:
+    need_to_convert = not isinstance(image, np.ndarray)
+
+    if need_to_convert:
+        image = np.asarray(image)
 
     patch_size = vit.model.patch_embed.proj.kernel_size[0]
 
@@ -159,8 +195,9 @@ def vis_vit(vit: ViTExtractor, image: np.ndarray, mean: TNormParam = MEAN, std:
     w_feat_map = img_tensor.shape[-2] // patch_size
     h_feat_map = img_tensor.shape[-1] // patch_size
 
-    with torch.no_grad():
-        attentions = vit.model.get_last_selfattention(img_tensor)
+    with temporary_setting_model_mode(vit, set_train=False):
+        with torch.no_grad():
+            attentions = vit.model.get_last_selfattention(img_tensor)
 
     nh = attentions.shape[1]
 
@@ -181,6 +218,9 @@ def vis_vit(vit: ViTExtractor, image: np.ndarray, mean: TNormParam = MEAN, std:
 
     arr = show_cam_on_image(image / image.max(), 0.6 * arr / arr.max())  # type: ignore
 
+    if need_to_convert:
+        arr = PIL.Image.fromarray(arr)
+
     return arr
 
 
