@@ -2,7 +2,7 @@ import inspect
 
 from oml.registry.losses import LOSSES_REGISTRY
 from oml.registry.miners import MINERS_REGISTRY
-from oml.registry.models import MODELS_REGISTRY
+from oml.registry.models import EXTRACTORS_REGISTRY
 from oml.registry.optimizers import OPTIMIZERS_REGISTRY
 from oml.registry.samplers import SAMPLERS_REGISTRY
 from oml.registry.schedulers import SCHEDULERS_REGISTRY
@@ -13,7 +13,7 @@ def show_registry() -> None:
     for name, registry in [
         ("Losses", LOSSES_REGISTRY),
         ("Miners", MINERS_REGISTRY),
-        ("Models", MODELS_REGISTRY),
+        ("Models", EXTRACTORS_REGISTRY),
         ("Optimizers", OPTIMIZERS_REGISTRY),
         ("Samplers", SAMPLERS_REGISTRY),
         ("Schedulers", SCHEDULERS_REGISTRY),
